@@ -17,8 +17,11 @@ class MonitoredClientSession(ClientSession):
         self._metrics = metrics
         super().__init__(*args, **kwargs)
 
-    async def _request(self, method: str, str_or_url: StrOrURL, **kwargs) -> ClientResponse:
+    async def _request(
+            self, method: str, str_or_url: StrOrURL, extended_metrics_labels: dict[str, str] | None = None, **kwargs
+    ) -> ClientResponse:
         labels = {'method': method.upper(), 'url': str(yarl.URL(str_or_url).with_query({}))}
+        labels |= extended_metrics_labels or {}
         with self._metrics.track('http_client__requests', labels) as tracker:
             try:
                 response = await super()._request(method, str_or_url, **kwargs)
